@@ -1,11 +1,9 @@
 #include "PAL.h"
-#include "PALImpl.h"
 
-PAL* PAL::instance = nullptr;
+PAL *PAL::instance = nullptr;
 
 PAL::PAL()
-	: m_PALImpl(new PALImpl())
-	, m_NotifyHandlerFunc(nullptr)
+	: m_PALImpl(new PALImpl()), m_notifyHandlerFunc(nullptr), onDownloadCallBack(nullptr)
 {
 }
 PAL::~PAL()
@@ -24,14 +22,14 @@ void PAL::release()
 
 void PAL::registerNotifyEvent(NotifyHandlerFunc handler)
 {
-	m_NotifyHandlerFunc = handler;
+	m_notifyHandlerFunc = handler;
 }
 
 void PAL::notifyCallback(NotifyCallback callback)
 {
-	if (m_NotifyHandlerFunc != nullptr)
+	if (m_notifyHandlerFunc != nullptr)
 	{
-		m_NotifyHandlerFunc(callback);
+		m_notifyHandlerFunc(callback);
 	}
 	else
 	{
@@ -43,3 +41,18 @@ std::vector<NotifyCallback> PAL::pollNotifyEvent()
 {
 	return m_notifyEvents;
 }
+
+void PAL::clearNotifyEvent()
+{
+	m_notifyEvents.clear();
+}
+
+bool PAL::openAppSettings()
+{
+	return m_PALImpl->openAppSettings();
+}
+
+bool PAL::checkPermission(int permission)
+{
+	return m_PALImpl->checkPermission(permission);
+}
\ No newline at end of file
